@@ -13,6 +13,7 @@ use Object::Tiny qw(
     base_uri
     index_file
     css_path
+    favicon_uri
     js_path
     versioned_title
     replace_css
@@ -24,7 +25,7 @@ use Object::Tiny qw(
 );
 
 use vars '$VERSION';
-$VERSION = '0.53';
+$VERSION = '0.54';
 
 sub go {
     my $class = shift;
@@ -151,6 +152,12 @@ sub start_nav {
         qq{<meta name="base-uri" content="$_" />}
     } @{ $self->{base_uri} };
 
+    my $favicon = '';
+    if (my $uri = $self->{favicon_uri}) {
+       my $type = $uri;
+       $type =~ s/.*\.([^.]+)/$1/;
+       $favicon = qq(<link rel="icon" type="img/$type" href="$uri">);
+    }
     print $fh _udent( <<"    EOF" );
     <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
     "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
@@ -160,6 +167,7 @@ sub start_nav {
         <title>$title</title>
         <link rel="stylesheet" type="text/css" href="$self->{css_path}podsite.css" />
         $base
+        $favicon
         <script type="text/javascript" src="$self->{js_path}podsite.js"></script>
         <meta name="generator" content="$class $version" />
       </head>
@@ -374,11 +382,11 @@ sub nav_header {
 sub version {
     my $self = shift;
     return $self->{version} if $self->{version};
-    require Module::Build::ModuleInfo;
+    require Module::Metadata;
     my $mod  = $self->main_module;
     my $file = Pod::Site::Search->instance->name2path->{$mod}
         or die "Could not find $mod\n";
-    my $info = Module::Build::ModuleInfo->new_from_file( $file )
+    my $info = Module::Metadata->new_from_file( $file )
         or die "Could not find $file\n";
     return $self->{version} ||= $info->version;
 }
@@ -652,6 +660,7 @@ F<httpd.conf> you can just do this:
   -j --js-path PATH         Path to CSS file
      --replace-css          Replace existing CSS file
      --replace-js           Replace existing JavaScript file
+     --favicon-uri URI      Add a favicon linking to the given URI
   -V --verbose              Incremental verbose mode.
   -h --help                 Print a usage statement and exit.
   -M --man                  Print the complete documentation and exit.
@@ -751,6 +760,10 @@ replace the CSS and JavaScript files, seeing as you might have changed them.
 If you want it to replace them (and in general you ought to), pass a true
 value for these parameters.
 
+=item C<favicon_uri>
+
+Link to favicon file.  Extracts type from extension.
+
 =item C<verbose>
 
 Pass a value greater than 0 for verbose output. The higher the number, the
@@ -1052,7 +1065,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2004-2010 David Wheeler. Some Rights Reserved.
+Copyright (c) 2004-2015 David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
